/*++++++++++++++
.IDENTIFICATION pmm_def.h
.LANGUAGE       C
.AUTHOR         Francois Ochsenbein [CDS]
.ENVIRONMENT    USNO-A2.0 Catalogue
.KEYWORDS       CDS Catalogue Server
.VERSION  1.0   01-Mar-1997
.VERSION  2.0   20-Oct-1998: USNO-A2.0
.COMMENTS       Structures & Definitions concerning the USNO-A2 Catalog
		only for internal usage.
	The compacted record is made 0f 7 bytes = 56 bits with
	Field_index (3) GSC/ACT(1) Q(1) RA(11) SD(22) MB(9) MR(9)
---------------*/

#ifndef PMM_DEF_def
#define PMM_DEF_def	0
#ifndef _ARG
#ifdef __STDC__
#define _ARG(A)	A    /* ANSI */
#else
#define _ARG(A)	()  /* non-ANSI */
#define const
#endif
#endif

/*===========================================================================
		Structures 
 *===========================================================================*/

#define XIZE		900000	/* 2.5 degrees	*/
#define Dstep		(3*XIZE)

/* Flags in PMM */
#define PMM_GSC		0x80	/* Correlated GSC entry */
#define PMM_ACT		0x80	/* Correlated ACT entry */
#define PMM_m		0x40	/* Magnitudes might be in error */

#define INDSIZ		(2+((3*XIZE)>>11))	/* Index size	*/
#define INDSIZ8		(2+((3*XIZE)>>18))	/* Index size	*/
static char header_text[] = "USNO-A2.0(7) t+728+4*1320, file: " ; 
static char header8text[] = "USNO-A2.0(8) t+756+4*12,   file: " ; 

typedef struct pmmhead {
    short reclen, zone ;	/* reclen is 7 or 8    	*/
    long  ntab ;		/* #elements in oblock 	*/
    long  otab ;		/* oblock[0] byte pos  	*/
    long  id0, ra0, sd0, id1, ra1, sd1 ;
    short plate[8] ;
    long  epoch[8] ;		/* JD */ 
    short mags[312];		/* Special Magnitudes	*/
    long oblock[INDSIZ] ;
} HEADER;

typedef struct pmmhead8 {
    short reclen, zone ;	/* reclen is ===> 8    	*/
    long  ntab ;		/* #elements in oblock 	*/
    long  otab ;		/* oblock[0] byte pos  	*/
    long  id0, ra0, sd0, id1, ra1, sd1 ;
    short plate[16] ;
    long  epoch[16] ;		/* JD */
    short mags[312];		/* Special Magnitudes	*/
    long oblock[INDSIZ8] ;
} HEADER8;

/*===========================================================================
		Prototypes Declarations
 *===========================================================================*/
 
#endif
